| Title: | Stability Analysis with Fuzzy Logic |
|---|---|
| Description: | It integrates 'fuzzy logic' into the analysis of genotype adaptability and stability. By classifying genotypes based on degrees of belonging, the package provides a detailed assessment of their behavior in different environmental groups. |
| Authors: | Maciel Douglas, O. [aut, cre] |
| Maintainer: | "Maciel Douglas, O." <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-07-10 22:47:06 UTC |
| Source: | https://github.com/cran/safuzzy |
Adaptability and Stability Analysis based on the interpretation of the Annicchiarico 1992 methodology, developed by Carneiro et al. 2019.
annicchiarico(data, env, gen, rep, var)annicchiarico(data, env, gen, rep, var)
data |
Data file (data.frame) with variables. |
env |
Column with environment information. |
gen |
Coluna contendo informações de genótipo. |
rep |
Column containing genotype information. |
var |
Variable to be analyzed. |
A data frame containing the following estimates:
GenGenotype.
WgGeneral recommendation index for environments.
WdRecommendation index for unfavorable environments.
WfRecommendation index for favorable environments.
GEMembership (%) to the general stability genotypes group.
PAMembership (%) to the poorly adapted genotypes group.
FAVMembership (%) to the favorable adapted genotypes group.
UNFMembership (%) to the unfavorable adapted genotypes group.
Douglas de Oliveira Maciel [email protected]
Carneiro, A. R. T., Sanglard, D. A., Azevedo, A. M., Souza, T. L. P. O. D., Pereira, H. S., & Melo, L. C. (2019). Fuzzy logic in automation for interpretation of adaptability and stability in plant breeding studies. Scientia Agricola, 76(2), 123-129.
data(ge_data) annicchiarico(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)data(ge_data) annicchiarico(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)
Adaptability and Stability Analysis based on the interpretation of the Cruz, Torres & Vencovsky (1989), developed by Carneiro et al. 2019.
cruz_torres_vencovsky(data, env, gen, rep, var)cruz_torres_vencovsky(data, env, gen, rep, var)
data |
Data file (data.frame) with variables. |
env |
Column with environment information. |
gen |
Coluna contendo informações de genótipo. |
rep |
Column containing genotype information. |
var |
Variable to be analyzed. |
A data frame containing the following estimates:
GenGenotype.
B_0Mean of the variable for each genotype.
B_1Regression coefficient ($B_1$) for each genotype.
B1_B2Regression coefficient ($B_1 + B_2$) for each genotype.
R2Coefficient of determination ($R^2$) for each genotype.
MdAFMembership (%) to the average adaptability to favorable environments genotypes group.
NdaMembership (%) to the poorly adapted genotypes group.
MdAGMembership (%) to the general adaptability to favorable environments genotypes group.
MaxGFMembership (%) to the maximum adaptability to favorable environments genotypes group.
MaxDesMembership (%) to the maximum adaptability to unfavorable environments environments group.
BEMembership (%) to the low stability genotypes group.
BPMembership (%) to the low yield genotypes group.
Douglas de Oliveira Maciel [email protected]
Carneiro, A. R. T., Sanglard, D. A., Azevedo, A. M., Souza, T. L. P. O. D., Pereira, H. S., & Melo, L. C. (2019). Fuzzy logic in automation for interpretation of adaptability and stability in plant breeding studies. Scientia Agricola, 76(2), 123-129.
data(ge_data) cruz_torres_vencovsky(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)data(ge_data) cruz_torres_vencovsky(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)
Adaptability and Stability Analysis based on the interpretation of the Eberhart & Russel 1966 methodology, developed by Carneiro et al. 2018.
eberhart_russell(data, env, gen, rep, var)eberhart_russell(data, env, gen, rep, var)
data |
Data file (data.frame) with variables. |
env |
Column with environment information. |
gen |
Coluna contendo informações de genótipo. |
rep |
Column containing genotype information. |
var |
Variable to be analyzed. |
A data frame containing the following estimates:
GenGenotype.
B_0Mean of the variable for each genotype.
B_1Regression coefficient ($B_1$) for each genotype.
R2Coefficient of determination ($R^2$) for each genotype.
GEMembership (%) to the general stability genotypes group.
PAMembership (%) to the poorly adapted genotypes group.
FAVMembership (%) to the favorable adapted genotypes group.
UNFMembership (%) to the unfavorable adapted genotypes group.
Douglas de Oliveira Maciel [email protected]
Carneiro, V. Q., Prado, A. L. D., Cruz, C. D., Carneiro, P. C. S., Nascimento, M., & Carneiro, J. E. D. S. (2018). Fuzzy control systems for decision-making in cultivars recommendation. Acta Scientiarum. Agronomy, 40, e39314.
data(ge_data) eberhart_russell(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)data(ge_data) eberhart_russell(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)
A real dataset containing the grain yield and plant heigth performance of upland rice lines
evaluated across multiple environments. This dataset is used to demonstrate
the application of the fuzzy logic methodology for adaptability and stability
analysis implemented in the safuzzy package.
ge_datage_data
A data frame (or tibble) with columns representing the experimental factors:
genotypeFactor representing the evaluated upland rice lines/genotypes.
environmentFactor representing the test environments (combinations of locations and crop years).
blockFactor representing the local control.
gyNumeric variable containing the grain yield performance (e.g., kg/ha).
phNumeric variable containing the plant heigth performance (e.g., cm).
The data consists of phenotypic evaluations of elite lines and commercial cultivars of upland rice. The analysis provides membership degrees that assist breeders in selecting stable and high-yielding genotypes for target environments.
Data obtained from the breeding trials conducted and published by Maciel et al. (2025).
Maciel, D. D. O., Guimarães, P. H. R., & Melo, P. G. S. (2025). Harnessing fuzzy logic for adaptive and stable selection of upland rice lines. Crop Breeding and Applied Biotechnology, 25(2), e527425213. doi:10.1590/1984-70332025v25n2a28
data(ge_data) head(ge_data)data(ge_data) head(ge_data)
Stability and Adaptability Analysis based on the interpretation of the Eberhart & Russel 1966 methodology, associated with the modified Lins & Bins (1988) methodology, developed by Carneiro et al. (2020).
hybrid(data, env, gen, rep, var)hybrid(data, env, gen, rep, var)
data |
Data file (data.frame) with variables. |
env |
Column with environment information. |
gen |
Coluna contendo informações de genótipo. |
rep |
Column containing genotype information. |
var |
Variable to be analyzed. |
Um data frame contendo as seguintes estimativas:
GenGenotype.
PIFPerformance index in favorable environments.
PIDPerformance index in unfavorable environments.
B_1Regression coefficient ($B_1$) for each genotype.
R2Standardized coefficient of determination ($R^2$) for each genotype.
GEMembership (%) to the general stability genotypes group.
PAMembership (%) to the poorly adapted genotypes group.
FAVMembership (%) to the favorable adapted genotypes group.
UNFMembership (%) to the unfavorable adapted genotypes group.
Douglas de Oliveira Maciel [email protected]
Carneiro, A. R. T., Sanglard, D. A., Azevedo, A. M., Souza, T. L. P. O. D., Pereira, H. S., Melo, L. C., & Carneiro, P. C. S. (2020). Fuzzy logic applied to different adaptability and stability methods in common bean. Pesquisa agropecuária brasileira, 55, e01609.
data(ge_data) hybrid(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)data(ge_data) hybrid(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)
Stability and Adaptability Analysis based on the interpretation of the modified Lins and Bins (1988) methodology.
lin_binns(data, env, gen, rep, var)lin_binns(data, env, gen, rep, var)
data |
Data file (data.frame) with variables. |
env |
Column with environment information. |
gen |
Coluna contendo informações de genótipo. |
rep |
Column containing genotype information. |
var |
Variable to be analyzed. |
A data frame containing the following estimates:
GenGenotype.
PIFPerformance index in favorable environments.
PIDPerformance index in unfavorable environments.
GEMembership (%) to the general stability genotypes group.
PAMembership (%) to the poorly adapted genotypes group.
FAVMembership (%) to the favorable adapted genotypes group.
UNFMembership (%) to the unfavorable adapted genotypes group.
Douglas de Oliveira Maciel [email protected]
Carneiro, P. C. S. (1998). Novas metodologias de análise da adaptabilidade e estabilidade de comportamento (Doctoral dissertation, Universidade Federal de Viçosa.).
data(ge_data) lin_binns(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)data(ge_data) lin_binns(data = ge_data, env = environment, gen = genotype, rep = block, var = gy)